@@ -17,27 +17,6 @@ Ideas:
     - Lazy loading modules, to be able to print stuff at once without having to print before the imports.
     - Add getting experience for groups and show the chars together (only one experience header instead of one per char). 
 
-
-Basic design principles for the scripting language: 
-    
-    - The action is character centered wherever possible and useful. 
-       -> char.say(text) instead of dialog(char, text)
-    
-    - Anything which affects only one character or any interaction between only a few characters which is initiated by one of them gets called from the character via char.action(). 
-       -> char.compete_skill(char2, skill_name) instead of competition_skill(char1, char2, skill_name)
-    
-    - Anything which affects the whole scene, or a whole group of not necessarily interacting characters gets called as basic function via action() or as class in its own right via class.action(). 
-       -> save([char1, char2]) instead of char1.save() char2.save()
-    
-    - The seperate class way should only be chosen, if the class can feel like a character in its own right and needs seperate states which may or may not be persistent over subsequent runs. 
-       -> For example AI.choose_the_way(players_answer) or music.action()
-    
-    - Data should be stored inside the chars wherever possible. If a script gets started with the same character again, the situation should resemble the previous one as much as possible, except where dictated otherwise by the story. 
-       -> char.save() instead of 'on quit' store_char_data(char) + 'on start' load_char_data(char)
-    
-    - Actions should be written as verb_noun or simply verb. 
-       -> char.say() and char.compete_skill() instead of char.text() and char.skill_compete()
-
 The code for the TextRPG can be found at U{http://dreehg.org/ArneBab/textrpg}
 
 """
@@ -67,7 +46,7 @@ __copyright__ = """
   MA 02110-1301 USA
 
 """ 
-__version__   = '0.3' 
+__version__   = '0.2' 
 __author__    = 'Arne Babenhauserheide' 
 # __date__      = '7th March 2007' 
 __url__       = 'http://rpg-1d6.sf.net' 
@@ -340,7 +319,7 @@ def select_battle_action(me, other, attack=True):
     
     @return: The result of the battle (won or lost, wounds)."""
     
-    if ask('Do you want to attack ' + other.name + '? (Yes, no) ').lower() in ['yes', 'y', '']: 
+    if ask('Do you want to attack ' + other.name + '? (Yes, no) ').lower() in ['Yes', 'y', '']: 
         diag("You attack " + other.name + ".")
         won, injuries_self, injuries_other = select_battle_style(me, other, attacker=True)
     else:
