@@ -14,7 +14,7 @@ elif version_info >= (3,0):
     print "- http://rpg-1d6.sf.net"
     exit()
 
-from lib.textrpg import story
+from rpg_lib.textrpg import story
 
 # Idee: Den Nutzer die Möglichkeiten gleich testen lassen. 
 from subprocess import call 
